==> notolog-0.9.1b8-py3-none-any.whl: notolog/lexemes/ru/settings_dialog.py <==
# Russian lexemes settings_dialog.py
lexemes = {
    # Настройки
    "window_title": "Настройки",

    "button_close": "Закрыть",

    "tab_general": "Общие",
    "tab_editor_config": "Редактор",
    "tab_viewer_config": "Просмотрщик",
    "tab_ai_config": "Настройки ИИ",

    "general_app_config_label": "Настройки приложения",
    "general_app_language_label": "Язык",
    "general_app_language_combo_placeholder_text": "Выбрать язык",
    "general_app_language_combo_accessible_description": "Язык интерфейса приложения",
    "general_app_theme_label": "Тема",
    "general_app_theme_combo_placeholder_text": "Выбрать тему",
    "general_app_theme_combo_accessible_description": "Тема интерфейса приложения",
    "general_app_main_menu_label": "Главное меню",
    "general_app_main_menu_checkbox": "Показать главное меню",
    "general_app_main_menu_checkbox_accessible_description": "Показать основное выпадающее меню приложения",
    "general_app_font_size_label": "Размер шрифта: {size}pt",
    "general_app_font_size_slider_accessible_description": "Настроить глобальный размер шрифта приложения",

    "general_statusbar_label": "Строка состояния",
    "general_statusbar_show_global_cursor_position_checkbox": "Показать глобальное положение курсора",
    "general_statusbar_show_global_cursor_position_checkbox_accessible_description":
        "Отображать глобальное положение курсора в строке состояния",

    "editor_config_label": "Настройки редактора",
    "editor_config_show_line_numbers_checkbox": "Показать номера строк",
    "editor_config_show_line_numbers_checkbox_accessible_description": "Отображать номера строк в редакторе",

    "viewer_config_label": "Настройки просмотрщика",
    "viewer_config_process_emojis_checkbox": "Преобразовать текстовые эмодзи в графику",
    "viewer_config_process_emojis_checkbox_accessible_description":
        "Преобразовать текстовые эмодзи в графические изображения",
    "viewer_config_highlight_todos_checkbox": "Выделить задачи TODO",
    "viewer_config_highlight_todos_checkbox_accessible_description": "Выделять задачи TODO в тексте",
    "viewer_config_open_link_confirmation_checkbox": "Требовать подтверждение перед открытием ссылок",
    "viewer_config_open_link_confirmation_checkbox_accessible_description":
        "Запрашивать подтверждение перед открытием ссылок",
    "viewer_config_save_resources_checkbox": "Автосохранение внешних изображений на диск",
    "viewer_config_save_resources_checkbox_accessible_description":
        "Автоматически сохраняет копии внешних изображений на диск для доступа без подключения к интернету.",

    "ai_config_openai_api_label": "API OpenAI",
    "ai_config_openai_api_url_input_placeholder_text": "URL API",
    "ai_config_openai_api_url_input_accessible_description": "URL API OpenAI",
    "ai_config_openai_api_key_input_placeholder_text": "Ключ API",
    "ai_config_openai_api_key_input_accessible_description": "Ключ API OpenAI",
    "ai_config_openai_api_supported_models_label": "Поддерживаемые модели",
    "ai_config_ai_model_names_combo_placeholder_text": "Выберите модель",
    "ai_config_ai_model_names_combo_accessible_description": "Выбор поддерживаемых моделей",

    "ai_config_base_label": "Основные параметры",
    "ai_config_base_system_prompt_label": "Системный запрос",
    "ai_config_base_system_prompt_edit_placeholder_text": "Базовый системный запрос, предшествующий каждому запросу",
    "ai_config_base_system_prompt_edit_accessible_description":
        "Базовый системный запрос, предшествующий каждому запросу. Простой текст.",
    "ai_config_base_response_max_tokens_label": "Максимальное количество токенов ответа",
    "ai_config_base_response_max_tokens_input_accessible_description":
        "Максимальное количество токенов для получения в ответе",
}

==> notolog-1.0.0-py3-none-any.whl: notolog/lexemes/ru/settings_dialog.py <==
# Russian lexemes settings_dialog.py
lexemes = {
    # Настройки
    "window_title": "Настройки",

    "button_close": "Закрыть",

    "tab_general": "Общие",
    "tab_editor_config": "Редактор",
    "tab_viewer_config": "Просмотрщик",
    "tab_ai_config": "Настройки ИИ",

    "general_app_config_label": "Настройки приложения",
    "general_app_language_label": "Язык",
    "general_app_language_combo_placeholder_text": "Выбрать язык",
    "general_app_language_combo_accessible_description": "Язык интерфейса приложения",
    "general_app_theme_label": "Тема",
    "general_app_theme_combo_placeholder_text": "Выбрать тему",
    "general_app_theme_combo_accessible_description": "Тема интерфейса приложения",
    "general_app_main_menu_label": "Главное меню",
    "general_app_main_menu_checkbox": "Показать главное меню",
    "general_app_main_menu_checkbox_accessible_description": "Показать основное выпадающее меню приложения",
    "general_app_font_size_label": "Размер шрифта: {size}pt",
    "general_app_font_size_slider_accessible_description": "Настроить глобальный размер шрифта приложения",

    "general_statusbar_label": "Строка состояния",
    "general_statusbar_show_global_cursor_position_checkbox": "Показать глобальное положение курсора",
    "general_statusbar_show_global_cursor_position_checkbox_accessible_description":
        "Отображать глобальное положение курсора в строке состояния",

    "editor_config_label": "Настройки редактора",
    "editor_config_show_line_numbers_checkbox": "Показать номера строк",
    "editor_config_show_line_numbers_checkbox_accessible_description": "Отображать номера строк в редакторе",

    "viewer_config_label": "Настройки просмотрщика",
    "viewer_config_process_emojis_checkbox": "Преобразовать текстовые эмодзи в графику",
    "viewer_config_process_emojis_checkbox_accessible_description":
        "Преобразовать текстовые эмодзи в графические изображения",
    "viewer_config_highlight_todos_checkbox": "Выделить задачи TODO",
    "viewer_config_highlight_todos_checkbox_accessible_description": "Выделять задачи TODO в тексте",
    "viewer_config_open_link_confirmation_checkbox": "Требовать подтверждение перед открытием ссылок",
    "viewer_config_open_link_confirmation_checkbox_accessible_description":
        "Запрашивать подтверждение перед открытием ссылок",
    "viewer_config_save_resources_checkbox": "Автосохранение внешних изображений на диск",
    "viewer_config_save_resources_checkbox_accessible_description":
        "Автоматически сохраняет копии внешних изображений на диск для доступа без подключения к интернету.",

    "ai_config_inference_module_label": "Модуль вывода",
    "ai_config_inference_module_names_combo_placeholder_text": "Выберите модуль",
    "ai_config_inference_module_names_combo_accessible_description": "Модули доступные для выбора",

    "ai_config_multi_turn_dialogue_checkbox":
        "Многоходовый диалог, который строится на предыдущих запросах для контекстуальной связности",
    "ai_config_multi_turn_dialogue_checkbox_accessible_description":
        "Многоходовый диалог, который строится на предыдущих запросах для контекстуальной связности",
    "ai_config_convert_to_md_checkbox": "Преобразовать результат в Markdown",
    "ai_config_convert_to_md_checkbox_accessible_description": "Преобразовать сообщение с результатом в Markdown",

    "ai_config_base_label": "Основные параметры",
}
